**Example 1: 删除溯源信息**



Input: 

```
tccli trp DeleteTraceData --cli-unfold-argument  \
    --TraceId awai9jd37ng3de7p3t
```

Output: 
```
{
    "Response": {
        "TraceId": "xx",
        "RequestId": "xx"
    }
}
```

